pub struct ColorMask { /* private fields */ }Expand description
TODO: use this type in API
Implementations
Sourceimpl ColorMask
impl ColorMask
pub const NONE: ColorMask
pub const R: ColorMask
pub const G: ColorMask
pub const B: ColorMask
pub const A: ColorMask
pub const RGB: ColorMask
pub const RGBA: ColorMask
Sourcepub fn from_bits(bits: u32) -> Option<ColorMask>
pub fn from_bits(bits: u32) -> Option<ColorMask>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> ColorMask
pub const fn from_bits_truncate(bits: u32) -> ColorMask
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> ColorMask
pub const unsafe fn from_bits_unchecked(bits: u32) -> ColorMask
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Sourcepub const fn intersects(&self, other: ColorMask) -> bool
pub const fn intersects(&self, other: ColorMask) -> bool
Returns true if there are flags common to both self and other.